#!/usr/bin/env mayapy
# -*- coding: utf8 -*-

import os
import sys
import logging
import argparse

import maya.standalone
from maya import cmds
import maya.OpenMayaUI as omui


"""
#
#   To paste in your Maya script editor
#

import os
import sys
import subprocess
script_path = "/PATH/TO/SCRIPT/vray_rt_batch_tests.py"
scene_path = cmds.file(q=1, sn=1)

# 1. Interactive VRayRT playblast
execfile(script_path)

# 2. Batch VRayRT playblast
os.environ.setdefault("PYTHONHOME", sys.prefix)
os.environ["DISPLAY"] = ":0.0"
os.environ["VRAY_FOR_MAYA_BATCH_PREVIEWS"] = "1"

exe = subprocess.check_output("which mayapy", shell=True).strip()
cmd = [exe, script_path, "--maya_scene", scene_path]

sub_p = subprocess.Popen(cmd, env=os.environ.copy(), stdout=subprocess.PIPE, stderr=subprocess.STDOUT)

# Display the subprocess output in real time
while True:
    stdout_line = sub_p.stdout.readline()
    if stdout_line == "":
        break
    print stdout_line.strip()

stdoutdata, stderrdata = sub_p.communicate()
sub_p.wait()

if sub_p.returncode != 0:
    raise Exception("Error when running batch command: %s" % stderrdata)
else:
    print "Subprocess ended successfully"

#
#
#
"""


if __name__ == "__main__":
    logger = logging.getLogger("TEST-VRAY-RT")

    # Init maya for batch
    try:
        is_batch = cmds.about(q=1, batch=1)
    except:
        maya.standalone.initialize()
        is_batch = cmds.about(q=1, batch=1)
    cmds.loadPlugin("vrayformaya.so", quiet=1)

    # For batch mode
    if is_batch:
        # Open batch scene
        parser = argparse.ArgumentParser(description="", epilog="")
        parser.add_argument("-ms", "--maya_scene", type=str, required=True, help="Maya scene to open")
        args = parser.parse_args(sys.argv[1:])
        cmds.file(args.maya_scene, open=1, force=1)

        # Force cam
        cam = "test_camShape"
        for existing_cam in cmds.ls(cameras=1):
            if cam == existing_cam:
                cmds.setAttr(existing_cam + ".renderable", 1)
            else:
                cmds.setAttr(existing_cam + ".renderable", 0)

        #
        # Set renderer to VRay RT
        #

        # -- Try with Maya cmds -- error: can't find the model editor in batch mode
        try:
            model_editor = cmds.playblast(activeEditor=1)
            cmds.modelEditor(model_editor, e=1, rendererOverrideName="VRayRT")
        except Exception as e:
            logger.warning("Unable to load VRayRT with Maya cmds:")
            logger.warning(e)

            # -- Try with open Maya -- error: Unknown "VRayRT" renderer
            try:
                view = omui.M3dView.active3dView()
                view.setRenderOverrideName("VRayRT")
            except Exception as e:
                logger.warning("Unable to load VRayRT with openMaya:")
                logger.warning(e)

    #
    # Run playblast
    #

    first = 1
    last = 50

    output_folder = "/PATH/TO/OUT/"
    output_folder = "/u/tcarpentier/Documents/Tests/Maya/quickPlayblast/"
    if cmds.about(q=1, batch=1):
        playblast_path = os.path.join(output_folder, "playblast_batch.mov")
    else:
        playblast_path = os.path.join(output_folder, "playblast_interactive.mov")

    # Refresh 1st frame
    cmds.currentTime(first, e=1)
    cmds.refresh(force=1)

    # Run playblast
    cmds.playblast(filename=playblast_path,
                   fo=1,
                   offScreen=1,
                   startTime=first,
                   endTime=last,
                   format='qt',
                   sequenceTime=0,
                   clearCache=1,
                   viewer=1,
                   showOrnaments=1,
                   fp=4,
                   percent=100,
                   compression="jpg",
                   quality=100,
                   wh=[960, 540]
                   )

    logger.info("Playblast location: %s" % playblast_path)

    if is_batch:
        maya.standalone.uninitialize()
